from .file_calculator import FileCalculator

# For linters and IDEs, this is a hint that FileCalculator is 
# the only thing that should be imported from this module. 
# It does not affect the actual behavior of the code.
__all__ = ["FileCalculator"] 
